@@ -91,7 +91,8 @@ plot_mixture <- function(x, y, type = 'score', npts = 200, degrees = 45,
                          par.strip.text = list(cex = 0.7),
                          par.settings = list(strip.background = list(col = '#9ECAE1'),
                                              strip.border = list(col = "black")),
-                         auto.key = list(space = 'right'), profile = FALSE, ...)
+                         auto.key = list(space = 'right', points=FALSE, lines=TRUE),
+                         profile = FALSE, ...)
 {
     dots <- list(...)
     pis <- extract.mirt(x, 'pis')
