@@ -52,11 +52,11 @@ boot.LR <- function(mod, mod2, R = 1000){
             dat <- simdata(model=mod)
             m0 <- mirt(dat, extract.mirt(mod, 'model'),
                        itemtype=extract.mirt(mod, 'itemtype'),
-                       verbose=FALSE, technical=list(warn=FALSE, message=FALSE))
+                       verbose=FALSE, technical=list(warn=FALSE, message=FALSE, omp=FALSE))
             if(!extract.mirt(m0, 'converged')) next
             m1 <- mirt(dat, extract.mirt(mod2, 'model'),
                        itemtype=extract.mirt(mod2, 'itemtype'),
-                       verbose=FALSE, technical=list(warn=FALSE, message=FALSE))
+                       verbose=FALSE, technical=list(warn=FALSE, message=FALSE, omp=FALSE))
             if(!extract.mirt(m1, 'converged')) next
             lr0 <- anova(m0, m1, verbose=FALSE)$X2[2L]
             if(lr0 <= 0) next
